..
   Template for the html base rendering

   Modified from
   https://github.com/sphinx-doc/sphinx/tree/master/sphinx/ext/autosummary/templates/autosummary/base.rst

lbfgsb.base.display\_start
==========================

.. currentmodule:: lbfgsb.base

.. autofunction:: display_start